$LOAD_PATH << '.'
require 'OpalKelly'

class Controller
  def initialize(config)
    @xem = OpalKelly::FrontPanel.new
    @config = config
    @data_ready = false
  end

  def check_device
    return OpalKelly::FrontPanel::NoError == @xem.OpenBySerial("")
  end

  def device_info
    puts "Device firmware version: #{@xem.GetDeviceMajorVersion}.#{@xem.GetDeviceMinorVersion}"
    puts "Device serial number: #{@xem.GetSerialNumber}"
    puts "Device ID: #{@xem.GetDeviceID}"
  end

  def device_init(bitfile)
    if !check_device
      puts "Device not present."
      return false
    end

    @xem.LoadDefaultPLLConfiguration

    if OpalKelly::FrontPanel::NoError != @xem.ConfigureFPGA(bitfile)
      puts "FPGA configuration failed."
      return false
    end

    if (false == @xem.IsFrontPanelEnabled)
      puts "FrontPanel support is not available."
      return(false)
    end
    
    return(true)
  end

  def rates
    while true
      w = 0
      while true
	@xem.UpdateWireOuts
	w = @xem.GetWireOutValue 0x21
	if (not @data_ready and w & 4 == 4) then
	  @data_ready = true
	  break
	elsif (@data_ready and w & 4 == 0) then
	  @data_ready = false 
	end
	sleep 0.1
      end

      channels = @config[:channels]
      len = (channels + 2) * 2
      buf = '\0' * len;
      @xem.ReadFromBlockPipeOut(0xa0, len, buf)
      v = buf.unpack('S' * (channels + 2))
      return v[1..(v.length-2)] if v[0] == 43520
    end
  end

  def i2c(address, command, data)
    @xem.SetWireInValue(1, address.to_i, 0x7f)
    @xem.SetWireInValue(2, command.to_i, 0xff)
    @xem.SetWireInValue(3, data.to_i, 0xff)
    @xem.UpdateWireIns
  end
end
