require 'optparse'
require 'thread'
$LOAD_PATH << '.'

options = { :channels => 40 }
mutex = Mutex.new

OptionParser.new do |o|
  o.banner = "Usage #{ARGV[0]} options"
  o.on('-t', '--test_controller', 'Check for the controller presence') { |b| options[:test_controller] = b }
  o.on('-s', '--simulation', 'Run in simulate mode') { |b| options[:simulate] = b }
  o.on('-r', '--remote', 'Run in remote and do not check for controller presence') { |b| options[:remote] = b }
  o.on('-c', '--channels=N', Integer, 'Define the number of channels') { |b| options[:channels] = b }
  o.on('-h') { puts o; exit }
  o.parse!
end
p options

rates = Array.new(options[:channels], 0)

ctl = nil
unless options[:simulate] == true
  unless options[:remote] == true
    require 'controller'
    ctl = Controller.new options
    if ctl.check_device 
      ctl.device_info
      ctl.device_init('fw.bit')
      options[:device] = true
      unless options[:test_controller] == true
	Thread.new do
	  while true
	    tmp = ctl.rates
	    mutex.synchronize { rates = tmp[0...options[:channels]] }
	  end
	end
      end
    else
      options[:remote] = true unless options[:test_controller] == true
      p 'device not found, running in remote'
    end
  end
else
  Thread.new do
    while true
      mutex.synchronize do
	rates.collect! { rand(3000) }
      end
      sleep 0.5
    end
  end
end



if options[:test_controller] == true
  Shoes.app do
    exit
  end
  exit
else
  Shoes.app :title => "DRM" do
    cells = []
    background "#eaeaea"
    stack :width => "100%" do 
      subtitle "Pmt dark rate", :align => "center"
    end
    flow do
      (1..options[:channels]).each do |i|
	stack :width => "19%", :margin => 15 do
	  background "#f0f0f0"
	  border black, :strokewidth => 2
	  inscription "Channel  # #{i}", :stroke => green, :align => "center", :margin => 1
	  cells << inscription("0", :align => "center", :margin => 2)
	end
      end
      stack :width => "100%" do
	para "pippo"
      end
    end

    animate(3) do 
      mutex.synchronize do
	cells.each_with_index { |cell, i| cell.replace(rates[i].to_i.to_s) }
      end
    end
  end
end
