#!/bin/bash

source `which setPortNumbers.sh`

PROLOG="BEGIN_PROLOG \
def_offset: 0x2700 \
def_channels: [ { channel: 0 enable: true dc_offset: @local::def_offset }, \
		{ channel: 1 enable: true dc_offset: @local::def_offset }, \
		{ channel: 2 enable: true dc_offset: @local::def_offset }, \
		{ channel: 3 enable: true dc_offset: @local::def_offset }, \
		{ channel: 4 enable: true dc_offset: @local::def_offset }, \
		{ channel: 5 enable: true dc_offset: @local::def_offset }, \
		{ channel: 6 enable: true dc_offset: @local::def_offset }, \
		{ channel: 7 enable: true dc_offset: @local::def_offset } ] \
END_PROLOG"

GENA="generator: V1495Driver \
  generator_ds50: {fragment_id: 0 sleep_us: 25000} \
  link_type: PCIE \
  link_number: 3 \
  vme_base: 0x01000000 \
  pulser_frequency: 1024 \
  acquisition_gate_us: 300 \
  memory_full_extension_us: 50"

GENB="generator: V172xDriver \
  generator_ds50: {fragment_id: 1} \
  link_type: PCIE \
  link_number: 0 \
  io_level: NIM \
  acquisition_gate_us: 400 \
  pre_trigger_us: 40 \
  acquisition_mode: SW \
  channels: @local::def_channels"

ART_CFG="physics: { \
  analyzers: { \
      canvasYY: { \
      module_type: WFCanvasFor8Channels \
      raw_label: daq \
      prescale: 100 \
      channel: 0 \
      adcmodule: YY \
    } \
  } \
  my_analysis_modules: [ canvasYY ] \
  end_paths: [ my_analysis_modules ] \
} \
source: \
{ \
  module_type: RawInput \
  waiting_time: 20 \
  resume_after_timeout: true \
  fragment_type_map: [[1, \"missed\"], [2, \"V1495\"], [3, \"V1720\"], [4, \"V1724\"]] \
} \
process_name: ONLINEDEMO"

xmlrpc http://localhost:$frPort0/RPC2 daq.init "$PROLOG daq: {max_fragment_size_words: 524288 fragment_receiver: {mpi_buffer_count: 10 $GENA first_event_builder_rank: 2 event_builder_count: 2}}" &

xmlrpc http://localhost:$frPort1/RPC2 daq.init "$PROLOG daq: {max_fragment_size_words: 524288 fragment_receiver: {mpi_buffer_count: 10 $GENB first_event_builder_rank: 2 event_builder_count: 2}}" &

artConfig=`echo $ART_CFG | sed 's/YY/0/g'`
xmlrpc http://localhost:$ebPort0/RPC2 daq.init "daq: {max_fragment_size_words: 524288 event_builder: {mpi_buffer_count: 10 first_fragment_receiver_rank: 0 fragment_receiver_count: 2 use_art: false print_event_store_stats: true}} ${artConfig}" &

artConfig=`echo $ART_CFG | sed 's/YY/1/g'`
xmlrpc http://localhost:$ebPort1/RPC2 daq.init "daq: {max_fragment_size_words: 524288 event_builder: {mpi_buffer_count: 10 first_fragment_receiver_rank: 0 fragment_receiver_count: 2 use_art: false print_event_store_stats: true}} ${artConfig}" &

wait
