////////////////////////////////////////////////////////////////////////
// Class:       WFCanvasFor8Channels
// Module Type: analyzer
// File:        WFCanvasFor8Channels_module.cc
//
// Generated at Sun Dec  2 12:23:06 2012 by Alessandro Razeto using artmod
// from art v1_02_04.
////////////////////////////////////////////////////////////////////////

#include "art/Framework/Core/EDAnalyzer.h"
#include "art/Framework/Principal/Handle.h"
#include "art/Framework/Principal/Event.h"
#include "art/Utilities/InputTag.h"
#include "art/Framework/Core/ModuleMacros.h"
#include "artdaq/DAQdata/Fragments.hh"
#include "ds50daq/DAQ/V172xFragment.hh"

#include "TROOT.h"
#include "TStyle.h"
#include "TApplication.h"
#include "TCanvas.h"
#include "TGraph.h"
#include "TAxis.h"
#include "TPad.h"

#include <numeric>
#include <vector>

namespace ds50 {
  class WFCanvasFor8Channels : public art::EDAnalyzer {
    public:
      explicit WFCanvasFor8Channels (fhicl::ParameterSet const & p);
      virtual ~WFCanvasFor8Channels ();

      void analyze (art::Event const & e) override;
      void beginJob() override;

    private:
      art::InputTag raw_label_;
      std::unique_ptr<TApplication> app_;
      std::unique_ptr<TCanvas> canvas_;
      std::unique_ptr<TPad> pad_;
      std::unique_ptr<TGraph> graph_[8];
      std::vector<Float_t> x_;
      int prescale_;
      int channel_;
      int adcmodule_;
     int eventcount_;
  };
}


ds50::WFCanvasFor8Channels::WFCanvasFor8Channels (fhicl::ParameterSet const & ps): raw_label_(ps.get<std::string> ("raw_label")), prescale_(ps.get<int> ("prescale")), channel_(ps.get<int> ("channel")), adcmodule_(ps.get<int> ("adcmodule")),eventcount_(0) {
}

ds50::WFCanvasFor8Channels::~WFCanvasFor8Channels() { }

void ds50::WFCanvasFor8Channels::analyze (art::Event const & e) {
    ++eventcount_;
    art::Handle<artdaq::Fragments> raw;
    e.getByLabel (raw_label_, raw);
    canvas_->SetWindowSize(canvas_->GetWw()+4,canvas_->GetWh()+26);
    for (int ch=0;ch<8;++ch){
        channel_ = ch;
        for (size_t i = 0; i < raw->size(); ++i) {
            const auto& frag((*raw)[i]);
            if (eventcount_ % prescale_) return;
            if (frag.fragmentID () != adcmodule_) continue;

            std::cout << "ch" << channel_ << ":" << frag.sequenceID ()
                      << " " << frag.fragmentID () << std::endl;

            V172xFragment b(frag);
            size_t board_id = b.board_id ();
            if (board_id) continue;
            
            size_t n_samples = std::distance (b.chDataBegin (1), b.chDataEnd(1));
            if (!x_.size ()) {
                x_.resize (n_samples);
                std::iota (x_.begin (), x_.end (), 0);
                std::for_each (x_.begin(), x_.end (), [](Float_t& d) { d *= 4;});
            }
            std::vector<Float_t> y(n_samples);
            std::copy (b.chDataBegin (channel_), b.chDataEnd(channel_), y.begin ());
            canvas_->cd(channel_+1);

            gPad->SetLeftMargin(0.05);
            gPad->SetRightMargin(0.001);            
            gPad->SetTickx(2);
            graph_[ch] = std::unique_ptr<TGraph>(new TGraph(n_samples,&(x_[0]), &(y[0])));
            graph_[ch]->SetTitle(Form("mod%d-ch%2d",adcmodule_,channel_));
            if(ch!=7){
                graph_[ch]->GetXaxis()->SetLabelSize(0);
            }
            graph_[ch]->Draw("AL");
        }
    }
    canvas_->Resize();
    canvas_->Modified ();
    canvas_->Update ();

}

void ds50::WFCanvasFor8Channels::beginJob() { 
    gROOT->Reset();
    if (!gApplication) {
        int    tmp_argc(0);
        app_ = std::unique_ptr<TApplication>(new TApplication("noapplication", &tmp_argc, 0));
    }
    int ww=1000;
    int wh=1200;
    std::string tmpString("module"+boost::lexical_cast<std::string>(adcmodule_));
    canvas_ = std::unique_ptr<TCanvas>(new TCanvas(tmpString.c_str(),Form("module-%d",adcmodule_),ww,wh));
    canvas_->Divide(1,8,0,0);
    gStyle->SetLabelSize(0.1,"Y");
    gStyle->SetLabelSize(0.1,"X");    
    gStyle->SetTitleFontSize(0.2);
    gStyle->SetTitleTextColor(4);
    gStyle->SetTitleX(0.9);    
}

DEFINE_ART_MODULE(ds50::WFCanvasFor8Channels)
